#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Jul 31 22:02:14 2017

@author: mark
"""

import logging
import matplotlib
import matplotlib.pyplot as plt
import scipy.cluster.hierarchy as cluster
import resultsanalysis.resultsoutput.plottinginput as plottinginput

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

def create_and_write_dendogram(linkage_matrix, labels, filename_stem, **kwargs):
    """This creates a dendogram plot and writes to file.
    """
    dendrogram_plot, dendrogram_plot_axis = create_dendogram(linkage_matrix, labels,
                                                             kwargs.get("figsize",(25,20)))
    append_plot_labels(dendrogram_plot_axis)
    fileformat = kwargs.get("fileformat", "eps")
    output_filename = create_outputfilename(filename_stem, fileformat)
    plt.savefig(output_filename, format=fileformat)
    plt.close(dendrogram_plot)
    return 0

def create_outputfilename(filename_stem, fileformat):
    """This creates a filename from the stem and file format.
    """
    return plottinginput.create_output_filename_from_stem(filename_stem, fileformat)

def create_dendogram(linkage_matrix, labels, figsize):
    """Creates a dendogram plot.
    """
    dendrogram_plot, dendrogram_plot_axis = create_plot_with_axis(figsize)
    cluster.dendrogram(linkage_matrix, labels=labels, orientation='right',
                       leaf_rotation=0, leaf_font_size=7,
                       ax=dendrogram_plot_axis)
    append_plot_labels(dendrogram_plot_axis)
    return dendrogram_plot, dendrogram_plot_axis

def append_plot_labels(plot_axis):
    """This adds labels to the dendrogram axis.
    """
    plot_axis.set_ylabel("Solvent")
    plot_axis.set_xlabel(r"Distance/$kJmol^{-1}$")

def create_plot_with_axis(figsize):
    """Function creates plot and plot axis.
    """
    return plottinginput.create_plot_with_axis(figsize)
