#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for testing the matrixinput script.

@author: mark
"""

import logging
import unittest
import numpy as np
import solventmapcreator.clusteringanalysis.matrixinput as matrixinput

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

class MatrixInputTestCase(unittest.TestCase):
    """Test case for matrix input script
    """
    def setUp(self):
        """Set up before tests.
        """
        self.input_filename = "resources/similarity_matrix_file.csv"
        self.expected_dict = {"labels":["poly_fit", "poly_fit2", "poly_fit3"],
                              "value_matrix":np.array([[0.0, 1.0, 4.0],
                                                  [1.0, 0.0, 3.0],
                                                  [4.0, 3.0, 0.0]])}
    def tearDown(self):
        """Clean up after tests.
        """
        del self.input_filename
        del self.expected_dict
    def test_parse_similarity_matrix_file_condensed_matrix(self):
        """Test to see if expected dictionary is produced.
        """
        expected_dict = {"labels":["poly_fit", "poly_fit2", "poly_fit3"],
                         "value_matrix":np.array([[0.0, 1.0, 4.0],
                                                  [1.0, 0.0, 3.0],
                                                  [4.0, 3.0, 0.0]]),
                         "condensed_matrix":np.array([1.0, 4.0, 3.0])}
        actual_dict = matrixinput.parse_similarity_matrix_file_condensed_matrix(self.input_filename)
        self.assertListEqual(sorted(expected_dict.keys()), sorted(actual_dict.keys()))
        self.assertListEqual(expected_dict["labels"], actual_dict["labels"])
        np.testing.assert_array_almost_equal(expected_dict["value_matrix"],
                                             actual_dict["value_matrix"])
        np.testing.assert_array_almost_equal(expected_dict["condensed_matrix"],
                                             actual_dict["condensed_matrix"])
    def test_append_condensed_matrix(self):
        """Test to see if matrix is appended as expected.
        """
        expected_dict = {"labels":["poly_fit", "poly_fit2", "poly_fit3"],
                         "value_matrix":np.array([[0.0, 1.0, 4.0],
                                                  [1.0, 0.0, 3.0],
                                                  [4.0, 3.0, 0.0]]),
                         "condensed_matrix":np.array([1.0, 4.0, 3.0])}
        matrixinput.append_condensed_matrix(self.expected_dict)
        self.assertListEqual(sorted(self.expected_dict.keys()), sorted(expected_dict.keys()))
        self.assertListEqual(self.expected_dict["labels"], expected_dict["labels"])
        np.testing.assert_array_almost_equal(self.expected_dict["value_matrix"],
                                             expected_dict["value_matrix"])
        np.testing.assert_array_almost_equal(self.expected_dict["condensed_matrix"],
                                             expected_dict["condensed_matrix"])
    def test_convert_to_condensed_matrix(self):
        """Test to see if expected matrix is returned.
        """
        expected_matrix = np.array([1.0, 4.0, 3.0])
        actual_matrix = matrixinput.convert_to_condensed_matrix(self.expected_dict["value_matrix"])
        np.testing.assert_array_almost_equal(expected_matrix, actual_matrix)
    def test_parse_similarity_matrix_file(self):
        """Test to see if expected matrix is read in.
        """
        actual_dict = matrixinput.parse_similarity_matrix_file(self.input_filename)
        self.assertListEqual(sorted(self.expected_dict.keys()), sorted(actual_dict.keys()))
        self.assertListEqual(self.expected_dict["labels"], actual_dict["labels"])
        np.testing.assert_array_almost_equal(self.expected_dict["value_matrix"],
                                             actual_dict["value_matrix"])
